@@ -2,7 +2,7 @@ package Test::SharedFork;
 use strict;
 use warnings;
 use base 'Test::Builder::Module';
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 use Test::Builder 0.32; # 0.32 or later is needed
 use Test::SharedFork::Scalar;
 use Test::SharedFork::Array;
@@ -24,6 +24,7 @@ BEGIN {
     for my $name (qw/ok skip todo_skip current_test/) {
         my $orig = *{"Test::Builder::${name}"}{CODE};
         *{"Test::Builder::${name}"} = sub {
+            local $Test::Builder::Level += 4;
             my @args = @_;
             $STORE->lock_cb(sub {
                 $orig->(@args);
@@ -80,6 +81,8 @@ yappo
 
 kazuhooku
 
+konbuizm
+
 =head1 SEE ALSO
 
 L<Test::TCP>, L<Test::Fork>, L<Test::MultipleFork>
